#
# spec file for package ghc-primitive
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name primitive
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.9.1.0
Release:        1.2
Summary:        Primitive memory-related operations
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-template-haskell-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-base-orphans-devel
BuildRequires:  ghc-base-orphans-prof
BuildRequires:  ghc-quickcheck-classes-base-devel
BuildRequires:  ghc-quickcheck-classes-base-prof
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-tagged-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
BuildRequires:  ghc-transformers-compat-devel
BuildRequires:  ghc-transformers-compat-prof
%endif

%description
This package provides various primitive memory-related operations.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc changelog.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Mon Mar 31 2025 Peter Simons <psimons@suse.com>
- Update primitive to version 0.9.1.0.
  [#]# Changes in version 0.9.1.0
  * Make fromListN functions good consumers for list fusion.
  * Add functions to improve `MutVar`'s interoperability with `IORef` and `STRef`.
  * Add `createPrimArray` and `createByteArray`.
  * Add `byteArrayAsForeignPtr` and `mutableByteArrayAsForeignPtr`.
  * Use `copyMutableByteArrayNonOverlapping#` in the implementation of `copyMutableByteArray`
    on sufficiently new GHCs. This does not change the contract for `copyMutableByteArray`.
    This function has always been documented as having undefined behavior when the slices
    overlap. However, overlaps previously were handled gracefully (with the semantics
    of C's `memmove`). Going forward, users who do not uphold `copyMutableByteArray`'s
    precondition will be met with unpredictable results.
  * Drop support for GHC 8.0.
* Tue Oct 22 2024 Peter Simons <psimons@suse.com>
- Update primitive to version 0.9.0.0 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Mar 16 2024 Peter Simons <psimons@suse.com>
- Update primitive to version 0.9.0.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Oct  5 2023 Peter Simons <psimons@suse.com>
- Update primitive to version 0.9.0.0.
  [#]# Changes in version 0.9.0.0
  * Add `withByteArrayContents`, `withMutableByteArrayContents`,
    `withPrimArrayContents`, `withMutablePrimArrayContents`.
  * Fix signature of `keepAlive`.
  * Remove re-export of `fromList` and `fromListN` from `Data.Primitive.Array`.
  * Use `mutableByteArrayContents#` in GHC 9.2+
  * Add `Prim` instance for `Complex`.
  * Add `getSizeofSmallMutableArray` that wraps `getSizeofSmallMutableArray#`
    from `GHC.Exts`.
  * Add default definitions for the `setByteArray#` and `setOffAddr#` methods,
    so they don't need to be defined explicitly anymore.
  * Add standalone `sizeOfType`/`alignmentOfType` (recommended over `sizeOf`/`alignment`)
    and `Prim` class methods `sizeOfType#`/`alignmentOfType#` (recommended over `sizeOf#`/`alignment#`)
  * Change `Show` instances of `PrimArray`, `Array`, and `SmallArray`. These
    previously used the `fromListN n [...]` form, but they now used the more
    terse `[...]` form.
  * Correct the `Read` instances of `Array` and `SmallArray`. These instances
    are supposed to be able to handle all three of these forms: `fromList [...]`,
    `fromListN n [...]`, and `[...]`. They had been rejected the last form, but
    this mistake was discovered by the test suite when the Show instances were
    changed.
* Thu Aug 17 2023 Peter Simons <psimons@suse.com>
- Update primitive to version 0.8.0.0 revision 1.
  [#]# Changes in version 0.8.0.0
  * Add `resizeSmallMutableArray` that wraps `resizeSmallMutableArray#` from
    `GHC.Exts`.
  * New module `Data.Primitive.PrimVar`. This is essentially `PrimArray` with
    element length 1. For types with `Prim` instances, this is a drop-in
    replacement for `MutVar` with fewer indirections.
  * `PrimArray`'s type argument has been given a nominal role instead of a phantom role.
    This is a breaking change.
  * Add `readCharArray`, `writeCharArray`, `indexCharArray` for operating on
    8-bit characters in a byte array.
  * When building with `base-4.17` and newer, re-export the `ByteArray` and
    `MutableByteArray` types from `base` instead of defining them in this
    library. This does not change the user-facing interface of
    `Data.Primitive.ByteArray`.
  * Add `keepAlive` that wraps `keepAlive#` for GHC 9.2 and newer. It
    falls back to using `touch` for older GHCs.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue Jan 17 2023 Peter Simons <psimons@suse.com>
- Update primitive to version 0.7.4.0 revision 1.
  [#]# Changes in version 0.7.4.0
  * Add Lift instances (#332)
  * Expose `copyPtrToMutablePrimArray`
  * Improve definitions for stimes (#326)
  * Support GHC 9.4. Note: GHC 9.4 is not released at the time of
    primitive-0.7.4.0's release, so this support might be reverted by
    a hackage metadata revision if things change.
  * Drop support for GHC 7.10
* Fri May 20 2022 Peter Simons <psimons@suse.com>
- Update primitive to version 0.7.3.0 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov  1 2021 psimons@suse.com
- Update primitive to version 0.7.3.0.
  [#]# Changes in version 0.7.3.0
  * Correct implementations of `*>` for `Array` and `SmallArray`.
  * Drop support for GHC < 7.10
  * Export `runByteArray` and `runPrimArray`.
  * Export `createArray` and `createSmallArray`.
  * Export `emptyByteArray`, `emptyPrimArray`, `emptyArray` and `emptySmallArray`.
* Wed Aug  4 2021 psimons@suse.com
- Update primitive to version 0.7.2.0.
  [#]# Changes in version 0.7.2.0
  * Add `thawByteArray` and `thawPrimArray`.
  * Changed the `Show` instance of `ByteArray`, so that all 8-bit words
    are rendered as two digits. For example, display `0x0D` instead of `0xD`.
* Fri May 14 2021 psimons@suse.com
- Update primitive to version 0.7.1.0 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Feb  5 2021 psimons@suse.com
- Update primitive to version 0.7.1.0 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Dec  8 2020 psimons@suse.com
- Update primitive to version 0.7.1.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Fri Jun 26 2020 psimons@suse.com
- Update primitive to version 0.7.1.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/primitive-0.7.1.0/src/changelog.md
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Wed May  6 2020 psimons@suse.com
- Update primitive to version 0.7.0.1.
  [#]# Changes in version 0.7.0.1
  * Allow building with GHC 8.12.
* Sun Dec 29 2019 psimons@suse.com
- Update primitive to version 0.7.0.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/primitive-0.7.0.0/src/changelog.md
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update primitive to version 0.6.4.0.
  [#]# Changes in version 0.6.4.0
  * Introduce `Data.Primitive.PrimArray`, which offers types and function
    for dealing with a `ByteArray` tagged with a phantom type variable for
    tracking the element type.
  * Implement `isByteArrayPinned` and `isMutableByteArrayPinned`.
  * Add `Eq1`, `Ord1`, `Show1`, and `Read1` instances for `Array` and
    `SmallArray`.
  * Improve the test suite. This includes having property tests for
    typeclasses from `base` such as `Eq`, `Ord`, `Functor`, `Applicative`,
    `Monad`, `IsList`, `Monoid`, `Foldable`, and `Traversable`.
  * Fix the broken `IsList` instance for `ByteArray`. The old definition
    would allocate a byte array of the correct size and then leave the
    memory unitialized instead of writing the list elements to it.
  * Fix the broken `Functor` instance for `Array`. The old definition
    would allocate an array of the correct size with thunks for erroring
    installed at every index. It failed to replace these thunks with
    the result of the function applied to the elements of the argument array.
  * Fix the broken `Applicative` instances of `Array` and `SmallArray`.
    The old implementation of `<*>` for `Array` failed to initialize
    some elements but correctly initialized others in the resulting
    `Array`. It is unclear what the old behavior of `<*>` was for
    `SmallArray`, but it was incorrect.
  * Fix the broken `Monad` instances for `Array` and `SmallArray`.
  * Fix the implementation of `foldl1` in the `Foldable` instances for
    `Array` and `SmallArray`. In both cases, the old implementation
    simply returned the first element of the array and made no use of
    the other elements in the array.
  * Fix the implementation of `mconcat` in the `Monoid` instance for
    `SmallArray`.
  * Implement `Data.Primitive.Ptr`, implementations of `Ptr` functions
    that require a `Prim` constraint instead of a `Storable` constraint.
  * Add `PrimUnlifted` instances for `TVar` and `MVar`.
  * Use `compareByteArrays#` for the `Eq` and `Ord` instances of
    `ByteArray` when building with GHC 8.4 and newer.
  * Add `Prim` instances for lots of types in `Foreign.C.Types` and
    `System.Posix.Types`.
  * Reexport `Data.Primitive.SmallArray` and `Data.Primitive.UnliftedArray`
    from `Data.Primitive`.
  * Add fold functions and map function to `Data.Primitive.UnliftedArray`.
    Add typeclass instances for `IsList`, `Ord`, and `Show`.
  * Add `defaultSetByteArray#` and `defaultSetOffAddr#` to
    `Data.Primitive.Types`.
* Mon May 14 2018 psimons@suse.com
- Update primitive to version 0.6.3.0.
  * Add `PrimMonad` instances for `ContT`, `AccumT`, and `SelectT` from
    `transformers`
  * Add `Eq`, `Ord`, `Show`, and `IsList` instances for `ByteArray`
  * Add `Semigroup` instances for `Array` and `SmallArray`. This allows
    `primitive` to build on GHC 8.4 and later.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 0.6.2.0 revision 1.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.6.1.0 revision 1 with cabal2obs.
* Sun Sep 27 2015 mimi.vx@gmail.com
- update to 0.6.1.0
  * Use more appropriate types in internal memset functions, which prevents
    overflows/segfaults on 64-bit systems.
  * Fixed a warning on GHC 7.10
  * Worked around a -dcore-lint bug in GHC 7.6/7.7
* Thu Apr  9 2015 mimi.vx@gmail.com
- update to 0.6
  + Split PrimMonad into two classes to allow automatic lifting of primitive
    operations into monad transformers. The internal operation has moved
    to the PrimBase class.
  + Fixed the test suite on older GHCs
  + Changed primitive_ to work around an oddity with GHC's code generation on
    certain versions that led to side effects not happening when used in
    conjunction with certain very unsafe IO performers.
  + Allow primitive to build on GHC 7.9
  + Implement cloneArray and cloneMutableArray primitives
    (with fall-back implementations for GHCs prior to version 7.2.1)
* Tue Sep  2 2014 peter.trommler@ohm-hochschule.de
- update to 0.5.2.1 for Haskell Platform 2014.2.0.0
- regenerate spec file
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- more transparent packaging (fewer macros)
* Sun Dec 30 2012 peter.trommler@ohm-hochschule.de
- expand macro in name tag to help source validator
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- make service localonly for Factory submission
* Wed Oct 17 2012 peter.trommler@ohm-hochschule.de
- update to 0.5.0.1 for Haskell Platform 2012.4.0.0 RC2
* Tue Oct  2 2012 peter.trommler@ohm-hochschule.de
- update to 0.5 from upstream
- required by ghc-vector 0.10 as part of Haskell Platform 2012.4.0.0
* Fri Jun  8 2012 peter.trommler@ohm-hochschule.de
- use cabal2spec 0.25.5 spec file template
* Thu Jan 19 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
